<?php

namespace EscapeWork\Manager\Medias\Http\Middleware;

use EscapeWork\Manager\Medias\Exceptions\MediableException;
use EscapeWork\Manager\Medias\Contracts\Mediable;
use EscapeWork\Manager\Medias\Exceptions\MediaSettingsException;
use Closure;

class MediableMiddleware
{

    /**
     * Run the request filter.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure  $next
     * @return mixed
     */
    public function handle($request, Closure $next)
    {
        $this->registerMediable($request->table, $request->model_id);

        return $next($request);
    }

    protected function registerMediable($table, $id)
    {
        app()->bind('EscapeWork\Manager\Medias\Contracts\Mediable', function ($app) use ($table, $id) {
            $configModel = config("manager-medias.medias.tables.$table.model");

            if (is_null($configModel)) throw new MediaSettingsException;

            $instance = $app->make($configModel);

            if (! ($instance instanceof Mediable)) throw new MediableException;

            return $instance->findOrFail($id);
        });
    }

}
